aboutsummaryrefslogtreecommitdiff
path: root/src/nvim/ex_cmds.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/nvim/ex_cmds.c')
-rw-r--r--src/nvim/ex_cmds.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/nvim/ex_cmds.c b/src/nvim/ex_cmds.c
index 6a7a713d39..8c536d4838 100644
--- a/src/nvim/ex_cmds.c
+++ b/src/nvim/ex_cmds.c
@@ -2347,9 +2347,9 @@ int do_ecmd(int fnum, char *ffname, char *sfname, exarg_T *eap, linenr_T newlnum
win_T *the_curwin = curwin;
buf_T *was_curbuf = curbuf;
// Set w_closing to avoid that autocommands close the window.
// Set b_locked for the same reason.
- the_curwin->w_closing = true;
+ the_curwin->w_locked = true;
buf->b_locked++;
if (curbuf == old_curbuf.br_buf) {
@@ -2365,7 +2365,7 @@ int do_ecmd(int fnum, char *ffname, char *sfname, exarg_T *eap, linenr_T newlnum
// Autocommands may have closed the window.
if (win_valid(the_curwin)) {
- the_curwin->w_closing = false;
+ the_curwin->w_locked = false;
}
buf->b_locked--;
@@ -2347,9 +2347,9 @@ int do_ecmd(int fnum, char *ffname, char *sfname, exarg_T *eap, linenr_T newlnum
win_T *the_curwin = curwin;
buf_T *was_curbuf = curbuf;
- // Set w_closing to avoid that autocommands close the window.
+ // Set w_locked to avoid that autocommands close the window.
// Set b_locked for the same reason.